@@ -312,7 +312,7 @@ class Scan:
             progress (:py:attr:`bool`, optional): Show a progress bar. Requires the :py:mod:`tqdm` package. Defaults to :py:attr:`True`.
         """
         iterator = _get_iterator(unp.nominal_values(self.q), progress)
-        to_remove
+        to_remove = []
         for i in iterator:
             im = image.Image(self.data["file"][i], self.data, self.metadata, pixel_maximum=self.pixel_max)
             if im.skip:
